@@ -30,6 +30,7 @@
 #include <QDate>
 #include <QLocale>
 #include <QSettings>
+#include <QByteArray>
 
 #include <time.h>
 
@@ -53,9 +54,10 @@
 #include <kis_tablet_support_win.h>
 #include <kis_tablet_support_win8.h>
 #include <kis_config.h>
+#include <QLibrary>
+#include <QMessageBox>
 
 #elif defined HAVE_X11
-#include <kis_tablet_support_x11.h>
 #include <kis_xi2_event_filter.h>
 #endif
 
@@ -86,6 +88,33 @@ void tryInitDrMingw()
     QString logFile = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation).replace(L'/', L'\\') + QStringLiteral("\\kritacrash.log");
     myExcHndlSetLogFileNameA(logFile.toLocal8Bit());
 }
+
+typedef enum ORIENTATION_PREFERENCE {
+    ORIENTATION_PREFERENCE_NONE = 0x0,
+    ORIENTATION_PREFERENCE_LANDSCAPE = 0x1,
+    ORIENTATION_PREFERENCE_PORTRAIT = 0x2,
+    ORIENTATION_PREFERENCE_LANDSCAPE_FLIPPED = 0x4,
+    ORIENTATION_PREFERENCE_PORTRAIT_FLIPPED = 0x8
+} ORIENTATION_PREFERENCE;
+typedef BOOL WINAPI (*pSetDisplayAutoRotationPreferences_t)(
+    ORIENTATION_PREFERENCE orientation
+);
+void resetRotation()
+{
+    QLibrary user32Lib("user32");
+    if (!user32Lib.load()) {
+        qWarning() << "Failed to load user32.dll! This really should not happen.";
+        return;
+    }
+    pSetDisplayAutoRotationPreferences_t pSetDisplayAutoRotationPreferences
+            = reinterpret_cast<pSetDisplayAutoRotationPreferences_t>(user32Lib.resolve("SetDisplayAutoRotationPreferences"));
+    if (!pSetDisplayAutoRotationPreferences) {
+        qDebug() << "Failed to load function SetDisplayAutoRotationPreferences";
+        return;
+    }
+    bool result = pSetDisplayAutoRotationPreferences(ORIENTATION_PREFERENCE_NONE);
+    qDebug() << "SetDisplayAutoRotationPreferences(ORIENTATION_PREFERENCE_NONE) returned" << result;
+}
 } // namespace
 #endif
 extern "C" int main(int argc, char **argv)
@@ -110,6 +139,10 @@ extern "C" int main(int argc, char **argv)
     QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings, true);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
+#if QT_VERSION >= 0x050900
+    QCoreApplication::setAttribute(Qt::AA_DisableShaderDiskCache, true);
+#endif
+
     const QString configPath = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
 
     bool singleApplication = true;
@@ -145,32 +178,46 @@ extern "C" int main(int argc, char **argv)
         qputenv("QT_ANGLE_PLATFORM", "d3d11");
 
         // Probe QPA auto OpenGL detection
-        KisOpenGL::probeWindowsQpaOpenGL(argc, argv, preferredOpenGLRenderer);
+        char *fakeArgv[2] = { argv[0], nullptr }; // Prevents QCoreApplication from modifying the real argc/argv
+        KisOpenGL::probeWindowsQpaOpenGL(1, fakeArgv, preferredOpenGLRenderer);
+
+        // HACK: https://bugs.kde.org/show_bug.cgi?id=390651
+        resetRotation();
 #endif
     }
 
-    KLocalizedString::setApplicationDomain("krita");
 
-    // first create the application so we can create a pixmap
-    KisApplication app(key, argc, argv);
+    QString language;
+    QString root;
+    {
+        // Create a temporary application to get the root
+        QCoreApplication app(argc, argv);
+        Q_UNUSED(app);
+        root = KoResourcePaths::getApplicationRoot();
+        QSettings languageoverride(configPath + QStringLiteral("/klanguageoverridesrc"), QSettings::IniFormat);
+        languageoverride.beginGroup(QStringLiteral("Language"));
+        language = languageoverride.value(qAppName(), "").toString();
+    }
+
 
 #ifdef Q_OS_LINUX
-    qputenv("XDG_DATA_DIRS", QFile::encodeName(KoResourcePaths::getApplicationRoot() + "share") + ":" + qgetenv("XDG_DATA_DIRS"));
+    {
+        QByteArray originalXdgDataDirs = qgetenv("XDG_DATA_DIRS");
+        if (originalXdgDataDirs.isEmpty()) {
+            // We don't want to completely override the default
+            originalXdgDataDirs = "/usr/local/share/:/usr/share/";
+        }
+        qputenv("XDG_DATA_DIRS", QFile::encodeName(root + "share") + ":" + originalXdgDataDirs);
+    }
 #else
-    qputenv("XDG_DATA_DIRS", QFile::encodeName(KoResourcePaths::getApplicationRoot() + "share"));
+    qputenv("XDG_DATA_DIRS", QFile::encodeName(root + "share"));
 #endif
 
     qDebug() << "Setting XDG_DATA_DIRS" << qgetenv("XDG_DATA_DIRS");
-    qDebug() << "Available translations" << KLocalizedString::availableApplicationTranslations();
-    qDebug() << "Available domain translations" << KLocalizedString::availableDomainTranslations("krita");
 
     // Now that the paths are set, set the language. First check the override from the language
     // selection dialog.
     {
-        QSettings languageoverride(configPath + QStringLiteral("/klanguageoverridesrc"), QSettings::IniFormat);
-        languageoverride.beginGroup(QStringLiteral("Language"));
-        QString language = languageoverride.value(qAppName(), "").toString();
-
         qDebug() << "Override language:" << language;
 
         if (!language.isEmpty()) {
@@ -179,11 +226,10 @@ extern "C" int main(int argc, char **argv)
             qputenv("LANG", language.split(":").first().toUtf8());
             QLocale locale(language.split(":").first());
             QLocale::setDefault(locale);
-            qDebug() << "Qt ui languages" << locale.uiLanguages();
         }
+#ifndef Q_OS_LINUX
         else {
             // And if there isn't one, check the one set by the system.
-            // XXX: This doesn't work, for some !@#$% reason.
             QLocale locale = QLocale::system();
             if (locale.name() != QStringLiteral("en")) {
                 qDebug() << "Setting Krita's language to:" << locale;
@@ -191,8 +237,18 @@ extern "C" int main(int argc, char **argv)
                 KLocalizedString::setLanguages(QStringList() << locale.name());
             }
         }
-
+#endif
     }
+
+    // first create the application so we can create a pixmap
+    KisApplication app(key, argc, argv);
+    KLocalizedString::setApplicationDomain("krita");
+
+    qDebug() << "Available translations" << KLocalizedString::availableApplicationTranslations();
+    qDebug() << "Available domain translations" << KLocalizedString::availableDomainTranslations("krita");
+    qDebug() << "Qt UI languages" << QLocale::system().uiLanguages() << qgetenv("LANG");
+
+
 #ifdef Q_OS_WIN
     QDir appdir(KoResourcePaths::getApplicationRoot());
     QString path = qgetenv("PATH");
@@ -268,23 +324,42 @@ extern "C" int main(int argc, char **argv)
 #if defined Q_OS_WIN
     {
         KisConfig cfg;
-        bool isUsingWin8PointerInput = false;
+        if (cfg.useWin8PointerInput() && !KisTabletSupportWin8::isAvailable()) {
+            cfg.setUseWin8PointerInput(false);
+        }
+        if (!cfg.useWin8PointerInput()) {
+            bool hasWinTab = KisTabletSupportWin::init();
+            if (!hasWinTab) {
+                if (KisTabletSupportWin8::isPenDeviceAvailable()) {
+                    // Use WinInk automatically
+                    cfg.setUseWin8PointerInput(true);
+                } else if (!cfg.readEntry("WarnedAboutMissingWinTab", false)) {
+                    if (KisTabletSupportWin8::isAvailable()) {
+                        QMessageBox::information(nullptr,
+                                i18n("Krita Tablet Support"),
+                                i18n("Cannot load WinTab driver and no Windows Ink pen devices are found. If you have a drawing tablet, please make sure the tablet driver is properly installed."),
+                                QMessageBox::Ok, QMessageBox::Ok);
+                    } else {
+                        QMessageBox::information(nullptr,
+                                i18n("Krita Tablet Support"),
+                                i18n("Cannot load WinTab driver. If you have a drawing tablet, please make sure the tablet driver is properly installed."),
+                                QMessageBox::Ok, QMessageBox::Ok);
+                    }
+                    cfg.writeEntry("WarnedAboutMissingWinTab", true);
+                }
+            }
+        }
         if (cfg.useWin8PointerInput()) {
             KisTabletSupportWin8 *penFilter = new KisTabletSupportWin8();
             if (penFilter->init()) {
                 // penFilter.registerPointerDeviceNotifications();
                 app.installNativeEventFilter(penFilter);
-                isUsingWin8PointerInput = true;
                 qDebug() << "Using Win8 Pointer Input for tablet support";
             } else {
                 qDebug() << "No Win8 Pointer Input available";
                 delete penFilter;
             }
         }
-        if (!isUsingWin8PointerInput) {
-            KisTabletSupportWin::init();
-            // app.installNativeEventFilter(new KisTabletSupportWin());
-        }
     }
 #endif
 
@@ -312,4 +387,3 @@ extern "C" int main(int argc, char **argv)
 
     return state;
 }
-
