@@ -191,6 +191,25 @@ KisPaintOpSettingsSP KisPaintOpSettings::clone() const
     return settings;
 }
 
+void KisPaintOpSettings::resetSettings(const QStringList &preserveProperties)
+{
+    QStringList allKeys = preserveProperties;
+    allKeys << "paintop";
+
+    QHash<QString, QVariant> preserved;
+    Q_FOREACH (const QString &key, allKeys) {
+        if (hasProperty(key)) {
+            preserved[key] = getProperty(key);
+        }
+    }
+
+    clearProperties();
+
+    for (auto it = preserved.constBegin(); it != preserved.constEnd(); ++it) {
+        setProperty(it.key(), it.value());
+    }
+}
+
 void KisPaintOpSettings::activate()
 {
 }
