@@ -97,6 +97,12 @@ public:
      */
     virtual KisPaintOpSettingsSP clone() const;
 
+    /**
+     * Removes all the settings from the object while keeping the paintop id,
+     * which is loaded to the object by the factory
+     */
+    void resetSettings(const QStringList &preserveProperties = QStringList());
+
     /**
      * @return the node the paintop is working on.
      */
