@@ -21,6 +21,13 @@
 
 #include "kis_global.h"
 #include "kis_paint_information.h"
+#include "kis_distance_information.h"
+#include "kis_spacing_information.h"
+#include "kis_timing_information.h"
+
+#include "kritaimage_export.h"
+
+class KisRenderedDab;
 
 namespace KisPaintOpUtils {
 
@@ -64,14 +71,13 @@ void paintLine(PaintOp &op,
                qreal fanCornersStep)
 {
     QPointF end = pi2.pos();
+    qreal endTime = pi2.currentTime();
 
     KisPaintInformation pi = pi1;
-    QPointF pt = pi1.pos();
     qreal t = 0.0;
 
-    while ((t = currentDistance->getNextPointPosition(pt, end)) >= 0.0) {
-        pt = pt + t * (end - pt);
-        pi = KisPaintInformation::mix(pt, t, pi, pi2);
+    while ((t = currentDistance->getNextPointPosition(pi.pos(), end, pi.currentTime(), endTime)) >= 0.0) {
+        pi = KisPaintInformation::mix(t, pi, pi2);
 
         if (fanCornersEnabled &&
             currentDistance->hasLastPaintInformation()) {
@@ -89,6 +95,23 @@ void paintLine(PaintOp &op,
          */
         pi.paintAt(op, currentDistance);
     }
+
+    /*
+     * Perform spacing and/or timing updates between dabs if appropriate. Typically, this will not
+     * happen if the above loop actually painted anything. This is because the
+     * getNextPointPosition() call before the paint operation will reset the accumulators in
+     * currentDistance and therefore make needsSpacingUpdate() and needsTimingUpdate() false. The
+     * temporal distance between pi1 and pi2 is typically too small for the accumulators to build
+     * back up enough to require a spacing or timing update after that. (The accumulated time values
+     * are updated not during the paint operation, but during the call to getNextPointPosition(),
+     * that is, updated during every paintLine() call.)
+     */
+    if (currentDistance->needsSpacingUpdate()) {
+        op.updateSpacing(pi2, *currentDistance);
+    }
+    if (currentDistance->needsTimingUpdate()) {
+        op.updateTiming(pi2, *currentDistance);
+    }
 }
 
 /**
@@ -99,7 +122,7 @@ void paintLine(PaintOp &op,
  * this the class stores two previosly requested points instead of the
  * last one.
  */
-class PositionHistory
+class KRITAIMAGE_EXPORT PositionHistory
 {
 public:
     /**
@@ -133,7 +156,7 @@ private:
     QPointF m_second;
 };
 
-bool checkSizeTooSmall(qreal scale, qreal width, qreal height)
+inline bool checkSizeTooSmall(qreal scale, qreal width, qreal height)
 {
     return scale * width < 0.01 || scale * height < 0.01;
 }
@@ -143,7 +166,7 @@ inline qreal calcAutoSpacing(qreal value, qreal coeff)
     return coeff * (value < 1.0 ? value : sqrt(value));
 }
 
-QPointF calcAutoSpacing(const QPointF &pt, qreal coeff, qreal lodScale)
+inline QPointF calcAutoSpacing(const QPointF &pt, qreal coeff, qreal lodScale)
 {
     const qreal invLodScale = 1.0 / lodScale;
     const QPointF lod0Point = invLodScale * pt;
@@ -151,43 +174,29 @@ QPointF calcAutoSpacing(const QPointF &pt, qreal coeff, qreal lodScale)
     return lodScale * QPointF(calcAutoSpacing(lod0Point.x(), coeff), calcAutoSpacing(lod0Point.y(), coeff));
 }
 
+KRITAIMAGE_EXPORT
 KisSpacingInformation effectiveSpacing(qreal dabWidth,
                                        qreal dabHeight,
                                        qreal extraScale,
+                                       bool distanceSpacingEnabled,
                                        bool isotropicSpacing,
                                        qreal rotation,
                                        bool axesFlipped,
                                        qreal spacingVal,
                                        bool autoSpacingActive,
                                        qreal autoSpacingCoeff,
-                                       qreal lodScale)
-{
-    QPointF spacing;
+                                       qreal lodScale);
 
-    if (!isotropicSpacing) {
-        if (autoSpacingActive) {
-            spacing = calcAutoSpacing(QPointF(dabWidth, dabHeight), autoSpacingCoeff, lodScale);
-        } else {
-            spacing = QPointF(dabWidth, dabHeight);
-            spacing *= spacingVal;
-        }
-    }
-    else {
-        qreal significantDimension = qMax(dabWidth, dabHeight);
-        if (autoSpacingActive) {
-            significantDimension = calcAutoSpacing(significantDimension, autoSpacingCoeff);
-        } else {
-            significantDimension *= spacingVal;
-        }
-        spacing = QPointF(significantDimension, significantDimension);
-        rotation = 0.0;
-        axesFlipped = false;
-    }
+KRITAIMAGE_EXPORT
+KisTimingInformation effectiveTiming(bool timingEnabled,
+                                     qreal timingInterval,
+                                     qreal rateExtraScale);
 
-    spacing *= extraScale;
+KRITAIMAGE_EXPORT
+QVector<QRect> splitAndFilterDabRect(const QRect &totalRect, const QVector<QRect> &dabRects, int idealPatchSize);
 
-    return KisSpacingInformation(spacing, rotation, axesFlipped);
-}
+KRITAIMAGE_EXPORT
+QVector<QRect> splitDabsIntoRects(const QVector<QRect> &dabRects, int idealNumRects, int diameter, qreal spacing);
 
 }
 
