@@ -70,10 +70,10 @@ void KisIteratorTest::writeBytes(const KoColorSpace * colorSpace)
     // Check allocation on tile boundaries
 
     // Allocate memory for a 2 * 5 tiles grid
-    quint8* bytes = allocatePixels(colorSpace, 64 * 64 * 10);
+    QScopedArrayPointer<quint8> bytes(allocatePixels(colorSpace, 64 * 64 * 10));
 
     // Covers 5 x 2 tiles
-    dev.writeBytes(bytes, 0, 0, 5 * 64, 2 * 64);
+    dev.writeBytes(bytes.data(), 0, 0, 5 * 64, 2 * 64);
 
     // Covers
     QCOMPARE(dev.extent(), QRect(0, 0, 64 * 5, 64 * 2));
@@ -84,19 +84,17 @@ void KisIteratorTest::writeBytes(const KoColorSpace * colorSpace)
 
     dev.clear();
     // Covers three by three tiles
-    dev.writeBytes(bytes, 10, 10, 130, 130);
+    dev.writeBytes(bytes.data(), 10, 10, 130, 130);
 
     QCOMPARE(dev.extent(), QRect(0, 0, 64 * 3, 64 * 3));
     QCOMPARE(dev.exactBounds(), QRect(10, 10, 130, 130));
 
     dev.clear();
     // Covers 11 x 2 tiles
-    dev.writeBytes(bytes, -10, -10, 10 * 64, 64);
+    dev.writeBytes(bytes.data(), -10, -10, 10 * 64, 64);
 
     QCOMPARE(dev.extent(), QRect(-64, -64, 64 * 11, 64 * 2));
     QCOMPARE(dev.exactBounds(), QRect(-10, -10, 640, 64));
-
-    delete[] bytes;
 }
 
 void KisIteratorTest::fill(const KoColorSpace * colorSpace)
@@ -106,28 +104,26 @@ void KisIteratorTest::fill(const KoColorSpace * colorSpace)
 
     QCOMPARE(dev.extent(), QRect(qint32_MAX, qint32_MAX, 0, 0));
 
-    quint8 * bytes = allocatePixels(colorSpace, 1);
+    QScopedArrayPointer<quint8> bytes(allocatePixels(colorSpace, 1));
 
-    dev.fill(0, 0, 5, 5, bytes);
+    dev.fill(0, 0, 5, 5, bytes.data());
     QCOMPARE(dev.extent(), QRect(0, 0, 64, 64));
     QCOMPARE(dev.exactBounds(), QRect(0, 0, 5, 5));
 
     dev.clear();
-    dev.fill(5, 5, 5, 5, bytes);
+    dev.fill(5, 5, 5, 5, bytes.data());
     QCOMPARE(dev.extent(), QRect(0, 0, 64, 64));
     QCOMPARE(dev.exactBounds(), QRect(5, 5, 5, 5));
 
     dev.clear();
-    dev.fill(5, 5, 500, 500, bytes);
+    dev.fill(5, 5, 500, 500, bytes.data());
     QCOMPARE(dev.extent(), QRect(0, 0, 8 * 64, 8 * 64));
     QCOMPARE(dev.exactBounds(), QRect(5, 5, 500, 500));
 
     dev.clear();
-    dev.fill(33, -10, 348, 1028, bytes);
+    dev.fill(33, -10, 348, 1028, bytes.data());
     QCOMPARE(dev.extent(), QRect(0, -64, 6 * 64, 17 * 64));
     QCOMPARE(dev.exactBounds(), QRect(33, -10, 348, 1028));
-
-    delete[] bytes;
 }
 
 void KisIteratorTest::sequentialIter(const KoColorSpace * colorSpace)
@@ -266,7 +262,7 @@ void KisIteratorTest::hLineIter(const KoColorSpace * colorSpace)
 {
     KisPaintDevice dev(colorSpace);
 
-    quint8 * bytes = allocatePixels(colorSpace, 1);
+    QScopedArrayPointer<quint8> bytes(allocatePixels(colorSpace, 1));
 
     QCOMPARE(dev.extent(), QRect(qint32_MAX, qint32_MAX, 0, 0));
 
@@ -278,7 +274,7 @@ void KisIteratorTest::hLineIter(const KoColorSpace * colorSpace)
     dev.clear();
     KisHLineIteratorSP it = dev.createHLineIteratorNG(0, 0, 128);
     do {
-        memcpy(it->rawData(), bytes, colorSpace->pixelSize());
+        memcpy(it->rawData(), bytes.data(), colorSpace->pixelSize());
     } while (it->nextPixel());
 
 
@@ -289,7 +285,7 @@ void KisIteratorTest::hLineIter(const KoColorSpace * colorSpace)
 
     it = dev.createHLineIteratorNG(0, 1, 128);
     do {
-        memcpy(it->rawData(), bytes, colorSpace->pixelSize());
+        memcpy(it->rawData(), bytes.data(), colorSpace->pixelSize());
     } while (it->nextPixel());
 
     QCOMPARE(dev.extent(), QRect(0, 0, 128, 64));
@@ -299,7 +295,7 @@ void KisIteratorTest::hLineIter(const KoColorSpace * colorSpace)
 
     it = dev.createHLineIteratorNG(10, 10, 128);
     do {
-        memcpy(it->rawData(), bytes, colorSpace->pixelSize());
+        memcpy(it->rawData(), bytes.data(), colorSpace->pixelSize());
     } while (it->nextPixel());
 
     QCOMPARE(dev.extent(), QRect(0, 0, 192, 64));
@@ -311,7 +307,7 @@ void KisIteratorTest::hLineIter(const KoColorSpace * colorSpace)
 
     it = dev.createHLineIteratorNG(10, 10, 128);
     do {
-        memcpy(it->rawData(), bytes, colorSpace->pixelSize());
+        memcpy(it->rawData(), bytes.data(), colorSpace->pixelSize());
     } while (it->nextPixel());
 
     QCOMPARE(dev.extent(), QRect(10, -15, 128, 64));
@@ -320,8 +316,6 @@ void KisIteratorTest::hLineIter(const KoColorSpace * colorSpace)
     it = dev.createHLineIteratorNG(10, 10, 128);
     it->nextRow();
     QCOMPARE(it->rawData(), it->oldRawData());
-    
-    delete[] bytes;
 }
 
 void KisIteratorTest::justCreation(const KoColorSpace * colorSpace)
@@ -337,7 +331,7 @@ void KisIteratorTest::vLineIter(const KoColorSpace * colorSpace)
 {
 
     KisPaintDevice dev(colorSpace);
-    quint8 * bytes = allocatePixels(colorSpace, 1);
+    QScopedArrayPointer<quint8> bytes(allocatePixels(colorSpace, 1));
 
     QCOMPARE(dev.extent(), QRect(qint32_MAX, qint32_MAX, 0, 0));
 
@@ -349,7 +343,7 @@ void KisIteratorTest::vLineIter(const KoColorSpace * colorSpace)
 
     KisVLineIteratorSP it = dev.createVLineIteratorNG(0, 0, 128);
     do {
-        memcpy(it->rawData(), bytes, colorSpace->pixelSize());
+        memcpy(it->rawData(), bytes.data(), colorSpace->pixelSize());
     } while(it->nextPixel());
     
     QCOMPARE((QRect) dev.extent(), QRect(0, 0, 64, 128));
@@ -360,7 +354,7 @@ void KisIteratorTest::vLineIter(const KoColorSpace * colorSpace)
 
     it = dev.createVLineIteratorNG(10, 10, 128);
     do {
-        memcpy(it->rawData(), bytes, colorSpace->pixelSize());
+        memcpy(it->rawData(), bytes.data(), colorSpace->pixelSize());
     } while(it->nextPixel());
 
     QCOMPARE(dev.extent(), QRect(0, 0, 64, 192));
@@ -372,7 +366,7 @@ void KisIteratorTest::vLineIter(const KoColorSpace * colorSpace)
 
     it = dev.createVLineIteratorNG(10, 10, 128);
     do {
-        memcpy(it->rawData(), bytes, colorSpace->pixelSize());
+        memcpy(it->rawData(), bytes.data(), colorSpace->pixelSize());
     } while(it->nextPixel());
 
     QCOMPARE(dev.extent(), QRect(10, -15, 64, 192));
@@ -381,16 +375,13 @@ void KisIteratorTest::vLineIter(const KoColorSpace * colorSpace)
     it = dev.createVLineIteratorNG(10, 10, 128);
     it->nextColumn();
     QCOMPARE(it->rawData(), it->oldRawData());
-    
-    delete[] bytes;
-
 }
 
 void KisIteratorTest::randomAccessor(const KoColorSpace * colorSpace)
 {
 
     KisPaintDevice dev(colorSpace);
-    quint8 * bytes = allocatePixels(colorSpace, 1);
+    QScopedArrayPointer<quint8> bytes(allocatePixels(colorSpace, 1));
 
     QCOMPARE(dev.extent(), QRect(qint32_MAX, qint32_MAX, 0, 0));
 
@@ -406,7 +397,7 @@ void KisIteratorTest::randomAccessor(const KoColorSpace * colorSpace)
     for (int y = 0; y < 128; ++y) {
         for (int x = 0; x < 128; ++x) {
             ac->moveTo(x, y);
-            memcpy(ac->rawData(), bytes, colorSpace->pixelSize());
+            memcpy(ac->rawData(), bytes.data(), colorSpace->pixelSize());
         }
     }
     QCOMPARE(dev.extent(), QRect(0, 0, 128, 128));
@@ -420,13 +411,11 @@ void KisIteratorTest::randomAccessor(const KoColorSpace * colorSpace)
     for (int y = 0; y < 128; ++y) {
         for (int x = 0; x < 128; ++x) {
             ac->moveTo(x, y);
-            memcpy(ac->rawData(), bytes, colorSpace->pixelSize());
+            memcpy(ac->rawData(), bytes.data(), colorSpace->pixelSize());
         }
     }
     QCOMPARE(dev.extent(), QRect(-54, -15, 192, 192));
     QCOMPARE(dev.exactBounds(), QRect(0, 0, 128, 128));
-
-    delete[] bytes;
 }
 
 
