@@ -52,8 +52,10 @@
 #include <kis_filter_strategy.h>
 #include <kis_guides_config.h>
 #include <kis_coordinates_converter.h>
+#include <kis_layer_utils.h>
 
 #include <KisMimeDatabase.h>
+#include <KoColor.h>
 #include <KoColorSpace.h>
 #include <KoColorProfile.h>
 #include <KoColorSpaceRegistry.h>
@@ -197,6 +199,28 @@ bool Document::setColorSpace(const QString &colorModel, const QString &colorDept
     return true;
 }
 
+QColor Document::backgroundColor()
+{
+    if (!d->document) return QColor();
+    if (!d->document->image()) return QColor();
+
+    const KoColor color = d->document->image()->defaultProjectionColor();
+    return color.toQColor();
+}
+
+bool Document::setBackGroundColor(const QColor &color)
+{
+    if (!d->document) return false;
+    if (!d->document->image()) return false;
+
+    KoColor background = KoColor(color, d->document->image()->colorSpace());
+    d->document->image()->setDefaultProjectionColor(background);
+
+    d->document->image()->setModified();
+    d->document->image()->initialRefreshGraph();
+
+    return true;
+}
 
 QString Document::documentInfo() const
 {
