@@ -182,7 +182,7 @@ public:
     bool isActive() const;
 
 public Q_SLOTS:
-    void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes) override;
+    void activate(ToolActivation activation, const QSet<KoShape*> &shapes) override;
     void deactivate() override;
     void canvasResourceChanged(int key, const QVariant & res) override;
     // Implement this slot in case there are any widgets or properties which need
@@ -211,10 +211,10 @@ protected:
     QPointF convertDocumentToWidget(const QPointF& pt);
 
     /// Convert from native (postscript points) to integer image pixel
-    /// coordinates. This truncates the floating point components and
+    /// coordinates. This rounds down (not truncate) the pixel coordinates and
     /// should be used in preference to QPointF::toPoint(), which rounds,
     /// to ensure the cursor acts on the pixel it is visually over.
-    QPoint convertToIntPixelCoord(KoPointerEvent *e);
+    QPoint convertToImagePixelCoordFloored(KoPointerEvent *e);
 
     QRectF convertToPt(const QRectF &rect);
 
@@ -286,8 +286,8 @@ protected:
     /// Override the cursor appropriately if current node is not editable
     bool overrideCursorIfNotEditable();
 
-    bool blockUntillOperationsFinished();
-    void blockUntillOperationsFinishedForced();
+    bool blockUntilOperationsFinished();
+    void blockUntilOperationsFinishedForced();
 
 protected:
     enum ToolMode {
@@ -302,6 +302,7 @@ protected:
 
     virtual void setMode(ToolMode mode);
     virtual ToolMode mode() const;
+    void setCursor(const QCursor &cursor);
 
 protected Q_SLOTS:
     /**
@@ -309,31 +310,6 @@ protected Q_SLOTS:
      */
     virtual void resetCursorStyle();
 
-    /**
-     * Called when the user requested undo while the stroke is
-     * active. If you tool supports undo of the part of its actions,
-     * override this method and do the needed work there.
-     *
-     * NOTE: Default implementation forwards this request to
-     *       requestStrokeCancellation() method, so that the stroke
-     *       would be cancelled.
-     */
-    virtual void requestUndoDuringStroke();
-
-    /**
-     * Called when the user requested the cancellation of the current
-     * stroke. If you tool supports cancelling, override this method
-     * and do the needed work there
-     */
-    virtual void requestStrokeCancellation();
-
-    /**
-     * Called when the image decided that the stroke should better be
-     * ended. If you tool supports long strokes, override this method
-     * and do the needed work there
-     */
-    virtual void requestStrokeEnd();
-
 private Q_SLOTS:
     void slotToggleFgBg();
     void slotResetFgBg();
