@@ -25,6 +25,21 @@
 
 #include <tiffio.h>
 
+#include <kis_annotation.h>
+#include <kis_paint_device.h>
+#include <kis_group_layer.h>
+#include <kis_generator_layer.h>
+#include <kis_clone_layer.h>
+#include <kis_external_layer_iface.h>
+#include <kis_adjustment_layer.h>
+#include <kis_image.h>
+#include <kis_paint_layer.h>
+#include <kis_types.h>
+#include <generator/kis_generator_layer.h>
+#include "kis_tiff_converter.h"
+#include <kis_iterator_ng.h>
+#include <kis_shape_layer.h>
+
 struct KisTIFFOptions;
 
 /**
@@ -41,36 +56,55 @@ public:
 
 public:
 
-    bool visit(KisPaintLayer *layer) override;
-    bool visit(KisGroupLayer *layer) override;
-    bool visit(KisGeneratorLayer*) override;
-
     bool visit(KisNode*) override {
         return true;
     }
-    bool visit(KisCloneLayer*) override {
-        return true;
+
+    bool visit(KisPaintLayer *layer) override {
+        return saveLayerProjection(layer);
     }
+
+    bool visit(KisGroupLayer *layer) override {
+        dbgFile << "Visiting on grouplayer" << layer->name() << "";
+        return visitAll(layer, true);
+    }
+
+    bool visit(KisGeneratorLayer *layer) override {
+        return saveLayerProjection(layer);
+    }
+
+    bool visit(KisCloneLayer *layer) override {
+        return saveLayerProjection(layer);
+    }
+
+    bool visit(KisExternalLayer *layer) override {
+        return saveLayerProjection(layer);
+    }
+
+    bool visit(KisAdjustmentLayer *layer) override {
+        return saveLayerProjection(layer);
+    }
+
     bool visit(KisFilterMask*) override {
         return true;
     }
+
     bool visit(KisTransformMask*) override {
         return true;
     }
+
     bool visit(KisTransparencyMask*) override {
         return true;
     }
+
     bool visit(KisSelectionMask*) override {
         return true;
     }
+
     bool visit(KisColorizeMask*) override {
         return true;
     }
-    bool visit(KisExternalLayer*) override;
 
-    bool visit(KisAdjustmentLayer*) override {
-        return true;
-    }
 
 private:
     inline TIFF* image() {
