@@ -86,10 +86,10 @@ private Q_SLOTS:
 
     void zoomOut();
     void zoomIn();
-
+#ifndef Q_OS_WIN
     void showInsertSpecialCharacterDialog();
     void insertCharacter(const QChar &c);
-
+#endif
     void setTextBold(QFont::Weight weight = QFont::Bold);
     void setTextWeightLight();
     void setTextWeightNormal();
@@ -113,7 +113,7 @@ private Q_SLOTS:
     void alignJustified();
 
     void setFont(const QString &fontName);
-    void setFontSize(const QString &size);
+    void setFontSize(qreal size);
     void setBaseline(KoSvgText::BaselineShiftMode baseline);
 
     void setSettings();
@@ -127,7 +127,7 @@ private Q_SLOTS:
 
 Q_SIGNALS:
 
-    void textUpdated(const QString &svg, const QString &defs);
+    void textUpdated(KoSvgTextShape *shape, const QString &svg, const QString &defs);
 
 protected:
 
@@ -142,12 +142,16 @@ private:
     void createActions();
     void enableRichTextActions(bool enable);
 
+
+
     Ui_WdgSvgTextEditor m_textEditorWidget;
     QTextEdit *m_currentEditor {0};
     QWidget *m_page {0};
     QList<QAction*> m_richTextActions;
     KoSvgTextShape *m_shape {0};
+#ifndef Q_OS_WIN
     KoDialog *m_charSelectDialog {0};
+#endif
     BasicXMLSyntaxHighlighter *m_syntaxHighlighter;
 
     QString m_searchKey;
